
Bullet (zlib) https://github.com/bulletphysics/bullet3

Eigen (MPL2) https://gitlab.com/libeigen/eigen

JSON for Modern C++ (MIT) https://github.com/nlohmann/json

OMPL (3-clause BSD license) https://ompl.kavrakilab.org/

OptimLib (Apache 2.0) https://github.com/kthohr/optim

quickhull ("Feel free to use.") https://github.com/akuukka/quickhull

Ruckig (MIT) https://github.com/pantor/ruckig

TinyXML-2 (zlib) https://github.com/leethomason/tinyxml2

yaml-cpp (MIT) https://github.com/jbeder/yaml-cpp
